/**
 * Created by tonyjiang on 16/3/14.
 */
import TakePhotoPlugin from '../interface'
import {ChanjetDecorator} from 'chanjet-plugin-base'

@ChanjetDecorator
class TakePhotoPluginChanjet extends TakePhotoPlugin{

    constructor(){
        super();

        const {ios , android} = mutants.env.constant.os;

        this.pluginName = {};
        this.pluginName[ios] = 'Camera';
        this.pluginName[android] = 'CameraPlugin';

        this.methodName = {};
        this.methodName[ios] = {
            takePhoto : 'takePhotoNoUpload'
        };
        this.methodName[android] = {
            takePhoto : 'takePhoto'
        };

    }
    
    _defaultTakePhotoOptions = {
        "quality" : 0
    }

    /**
     *
     * @param options
     *      @property options.quality 0:高质量(默认) , 1:中等质量 , 2:低质量
     * @param callback 执行完成后回调
     * @param requestId 应用自己分配的值,用于在restore时判断数据来源进行后续操作.
     *
     */
    takePhoto(options , callback , requestId = ''){
        Object.assign(options , this._defaultTakePhotoOptions , options);

        const {os} = mutants.env;

        const pluginName = this.pluginName[os];
        const methodName = this.methodName[os].takePhoto;

        cordova.exec(
            this._takePhotoSuccess.bind(this , callback , requestId),
            this._takePhotoFailed.bind(this , callback , requestId),
            pluginName , methodName , [options , requestId]
        );

    }

    _takePhotoSuccess(callback , requestId , data){

        const {os} = mutants.env;
        const {android , ios} = mutants.env.constant.os;
        //如果是安卓
        if(os == android){
            const result = {
                resultCode : data.result,
                message : data.message,
                requestId : requestId,
                body : {
                    data : data.urls
                }
            };
            callback(result);
        }else{//如果是ios
            const rsJSON = JSON.parse(data);

            const resultCode = rsJSON.code == 0 ? 0 : 1;
            const message = rsJSON.code == 0 ? rsJSON.msg : JSON.parse(rsJSON.msg);
            const result = {
                resultCode : resultCode,
                message : message,
                requestId : requestId,
                body : {
                    data : [rsJSON.data.nativeUrl]
                }
            }

            callback(result);
        }


    }

    _takePhotoFailed(callback , requestId , error){
        const rs = {
            resultCode : 1,
            message : error,
            requestId : requestId,
            body : {}
        };
        callback(rs);
    }

}

export default TakePhotoPluginChanjet